<?php

namespace FiloBlu\DynamicCustomOptions\Controller\Adminhtml\DynamicCustomOptions;

abstract class DynamicCustomOptions extends \Magento\Backend\App\Action
{
    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $coreRegistry = null;

    /**
     * @var \Magento\Framework\App\Response\Http\FileFactory
     */
    protected $fileFactory;

    /**
     * @var \Magento\Framework\Stdlib\DateTime\Filter\Date
     */
    protected $dateFilter;

    /**
     * @var \FiloBlu\DynamicCustomOptions\Model\DynamicCustomOptionsFactory
     */
    protected $dynamicCustomOptionsFactory;

    /**
     * @var \Psr\Log\LoggerInterface
     */
    protected $logger;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\Registry $coreRegistry
     * @param \Magento\Framework\App\Response\Http\FileFactory $fileFactory
     * @param \Magento\Framework\Stdlib\DateTime\Filter\Date $dateFilter
     * @param \FiloBlu\DynamicCustomOptions\Model\DynamicCustomOptionsFactory $dynamicCustomOptionsFactory
     * @param \Psr\Log\LoggerInterface $logger
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Registry $coreRegistry,
        \Magento\Framework\App\Response\Http\FileFactory $fileFactory,
        \Magento\Framework\Stdlib\DateTime\Filter\Date $dateFilter,
        \FiloBlu\DynamicCustomOptions\Model\DynamicCustomOptionsFactory $dynamicCustomOptionsFactory,
        \Psr\Log\LoggerInterface $logger
    ) {
        parent::__construct($context);
        $this->coreRegistry = $coreRegistry;
        $this->fileFactory = $fileFactory;
        $this->dateFilter = $dateFilter;
        $this->dynamicCustomOptionsFactory = $dynamicCustomOptionsFactory;
        $this->logger = $logger;
    }

    /**
     * Initiate DynamicCustomOptions
     *
     * @return void
     */
    protected function _initDynamicCustomOptions()
    {
        $dynamicCustomOptions = $this->dynamicCustomOptionsFactory->create();
        $this->coreRegistry->register(
            'current_dynamiccustomoptions',
            $dynamicCustomOptions
        );
        $id = (int)$this->getRequest()->getParam('id');

        if (!$id && $this->getRequest()->getParam('dynamiccustomoptions_id')) {
            $id = (int)$this->getRequest()->getParam('dynamiccustomoptions_id');
        }

        if ($id) {
            $this->coreRegistry->registry('current_dynamiccustomoptions')->load($id);
        }
    }

    /**
     * Initiate action
     *
     * @return DynamicCustomOptions
     */
    protected function _initAction()
    {
        $this->_view->loadLayout();
        $this->_setActiveMenu('FiloBlu_DynamicCustomOptions::config')
            ->_addBreadcrumb(__('Dynamic Custom Options'), __('Dynamic Custom Options'));
        return $this;
    }

    /**
     * Returns result of current user permission check on resource and privilege
     *
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('FiloBlu_DynamicCustomOptions::config');
    }
}