<?php

namespace FiloBlu\DynamicCustomOptions\Controller\Adminhtml\DynamicCustomOptions;

class Save extends \FiloBlu\DynamicCustomOptions\Controller\Adminhtml\DynamicCustomOptions\DynamicCustomOptions
{

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\Registry $coreRegistry
     * @param \Magento\Framework\App\Response\Http\FileFactory $fileFactory
     * @param \Magento\Framework\Stdlib\DateTime\Filter\Date $dateFilter
     * @param \FiloBlu\DynamicCustomOptions\Model\DynamicCustomOptionsFactory $dynamicCustomOptionsFactory
     * @param \Psr\Log\LoggerInterface $logger
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Registry $coreRegistry,
        \Magento\Framework\App\Response\Http\FileFactory $fileFactory,
        \Magento\Framework\Stdlib\DateTime\Filter\Date $dateFilter,
        \FiloBlu\DynamicCustomOptions\Model\DynamicCustomOptionsFactory $dynamicCustomOptionsFactory,
        \Psr\Log\LoggerInterface $logger
    ) {

        parent::__construct($context, $coreRegistry, $fileFactory, $dateFilter, $dynamicCustomOptionsFactory, $logger);
    }

    /**
     * DynamicCustomOptions save action
     *
     * @return void
     */
    public function execute()
    {
        if (!$this->getRequest()->getPostValue()) {
            $this->_redirect('filobludynamiccustomoptionsadmin/*/');
        }

        try {
            /** @var $model \FiloBlu\DynamicCustomOptions\Model\DynamicCustomOptions */
            $model = $this->dynamicCustomOptionsFactory->create();
            $this->_eventManager->dispatch(
                'adminhtml_controller_dynamiccustomoptions_prepare_save',
                ['request' => $this->getRequest()]
            );
            $data = $this->getRequest()->getPostValue();
            
//            if ($data['from_date']) {
//                $data['from_date'] = $this->dateFilter->filter($data['from_date']);
//            }
//            if ($data['to_date']) {
//                $data['to_date'] = $this->dateFilter->filter($data['to_date']);
//            }
               
            $id = $this->getRequest()->getParam('dynamiccustomoptions_id');
            if ($id) {
                $model->load($id);
            }

            $validateResult = $model->validateData(new \Magento\Framework\DataObject($data));
            if ($validateResult !== true) {
                foreach ($validateResult as $errorMessage) {
                    $this->messageManager->addErrorMessage($errorMessage);
                }
                $this->_session->setPageData($data);
                $this->_redirect('filobludynamiccustomoptionsadmin/*/edit', ['id' => $model->getId()]);
                return;
            }

            $data = $this->prepareData($data);
            $model->loadPost($data);

            $this->_session->setPageData($model->getData());

            $model->save();
            $this->messageManager->addSuccessMessage(__('You saved the dynamic custom options.'));
            $this->_session->setPageData(false);
            if ($this->getRequest()->getParam('back')) {
                $this->_redirect('filobludynamiccustomoptionsadmin/*/edit', ['id' => $model->getId()]);
                return;
            }
            $this->_redirect('filobludynamiccustomoptionsadmin/*/');
            return;
        } catch (\Magento\Framework\Exception\LocalizedException $e) {
            $this->messageManager->addErrorMessage($e->getMessage());
            $id = (int)$this->getRequest()->getParam('dynamiccustomoptions_id');
            if (!empty($id)) {
                $this->_redirect('filobludynamiccustomoptionsadmin/*/edit', ['id' => $id]);
            } else {
                $this->_redirect('filobludynamiccustomoptionsadmin/*/new');
            }
            return;
        } catch (\Exception $e) {
            $this->messageManager->addErrorMessage(
                __('Something went wrong while saving the dynamic custom options data. Please review the error log.')
            );
            $this->logger->critical($e);
            $data = !empty($data) ? $data : [];
            $this->_session->setPageData($data);
            $this->_redirect('filobludynamiccustomoptionsadmin/*/edit', ['id' => $this->getRequest()->getParam('dynamiccustomoptions_id')]);
            return;
        }
    }

    /**
     * Prepares specific data
     *
     * @param array $data
     * @return array
     */
    protected function prepareData($data)
    {

        if (isset($data['rule']['conditions'])) {
            $data['conditions'] = $data['rule']['conditions'];
        }

        unset($data['rule']);

        return $data;
    }
}