<?php

namespace FiloBlu\DynamicCustomOptions\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

class InstallSchema implements InstallSchemaInterface
{

    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $installer = $setup;
        $installer->startSetup();

        $table = $installer->getConnection()->newTable(
            $installer->getTable('filoblu_dynamiccustomoptions')
        )->addColumn(
            'dynamiccustomoptions_id',
            Table::TYPE_INTEGER,
            null,
            ['identity' => true, 'unsigned' => true, 'nullable' => false, 'primary' => true],
            'Dynamic Custom Options Id'
        )->addColumn(
            'name',
            Table::TYPE_TEXT,
            255,
            [],
            'Name'
        )->addColumn(
            'description',
            Table::TYPE_TEXT,
            '64k',
            [],
            'Description'
        )->addColumn(
            'json_config',
            Table::TYPE_TEXT,
            '64k',
            [],
            'Json Custom Options Config'
        )
//                ->addColumn(
//            'from_date',
//            Table::TYPE_DATE,
//            null,
//            ['nullable' => true, 'default' => null],
//            'From'
//        )
//                ->addColumn(
//            'to_date',
//            Table::TYPE_DATE,
//            null,
//            ['nullable' => true, 'default' => null],
//            'To'
//        )
                ->addColumn(
            'is_active',
            Table::TYPE_SMALLINT,
            null,
            ['nullable' => false, 'default' => '0'],
            'Is Active'
        )->addColumn(
            'conditions_serialized',
            Table::TYPE_TEXT,
            '2M',
            [],
            'Conditions Serialized'
        )->addColumn(
            'is_cron_active',
            Table::TYPE_SMALLINT,
            null,
            ['nullable' => false, 'default' => '0'],
            'Is Cron Active'
        )->addColumn(
            'do_actions_on_save',
            Table::TYPE_SMALLINT,
            null,
            ['nullable' => false, 'default' => '0'],
            'Do Actions On Save'
        )
//                ->addColumn(
//            'sort_order',
//            Table::TYPE_INTEGER,
//            null,
//            ['unsigned' => true, 'nullable' => false, 'default' => '0'],
//            'Sort Order (Priority)'
//        )
                
        ->setComment(
            'Dynamic Custom Options Rules'
        );

        $installer->getConnection()->createTable($table);
        
        $table = $installer->getConnection()->newTable(
            $installer->getTable('filoblu_dynamiccustomoptions_products')
        )->addColumn(
            'dynamiccustomoptions_id',
            Table::TYPE_INTEGER,
            null,
            ['unsigned' => true, 'nullable' => false, 'primary' => true],
            'Dynamic Custom Options Id'
        )->addForeignKey(
            $installer->getFkName(
                'filoblu_dynamiccustomoptions_products',
                'dynamiccustomoptions_id',
                'filoblu_dynamiccustomoptions',
                'dynamiccustomoptions_id'
            ),
            'dynamiccustomoptions_id',
            $installer->getTable('filoblu_dynamiccustomoptions'),
            'dynamiccustomoptions_id',
            \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
            \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
        )->addColumn(
            'product_id',
            Table::TYPE_INTEGER,
            null,
            ['unsigned' => true, 'nullable' => false, 'primary' => true],
            'Product Id'
        )->addColumn(
            'option_id',
            Table::TYPE_INTEGER,
            null,
            ['unsigned' => true, 'nullable' => false, 'primary' => true],
            'Option Id'
        )->addForeignKey(
            $installer->getFkName(
                'filoblu_dynamiccustomoptions_products',
                'option_id',
                'catalog_product_option',
                'option_id'
            ),
            'option_id',
            $installer->getTable('catalog_product_option'),
            'option_id',
            \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
            \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
        )
//                ->addColumn(
//            'store_id',
//            Table::TYPE_INTEGER,
//            null,
//            ['unsigned' => true, 'nullable' => false, 'primary' => true],
//            'Store Id'
//        )
                ->setComment(
            'Dynamic Custom Options Rules Match'
        );

        $installer->getConnection()->createTable($table);
        $installer->endSetup();
    }
}